==> monica-4.0.0p0.tgz: www/monica/resources/lang/id/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Bagaimana hari Anda? Anda bisa menilainya sekali setiap hari.',
    'journal_come_back' => 'Terima kasih. Kembalilah besok untuk menilai hari Anda lagi.',
    'journal_description' => 'Catatan: Jurnal mencantumkan entri jurnal mandiri, dan entri otomatis seperti Aktifitas yang telah selesai dilakukan dengan kontak Anda. Meskipun Anda dapat menghapus entri jurnal secara mandiri, Anda harus menghapus aktifitas secara langsung pada halaman kontak.',
    'journal_add' => 'Tambahkan sebuah entri jurnal',
    'journal_edit' => 'Sunting sebuah entri jurnal',
    'journal_empty' => 'Jurnal kosong',
    'journal_created_at' => 'Dibuat pada {date}',
    'journal_created_automatically' => 'Dibuat secara otomatis',
    'journal_entry_type_journal' => 'Entri jurnal',
    'journal_entry_type_activity' => 'Aktifitas',
    'journal_entry_rate' => 'Anda telah menilai hari Anda.',
    'journal_add_comment' => 'Apakah Anda ingin untuk menambahkan komentar (opsional)?',
    'journal_show_comment' => 'Tampilkan komentar',
    'entry_delete_success' => 'Entri jurnal telah berhasil dihapus.',
    'journal_add_title' => 'Judul (opsional)',
    'journal_add_date' => 'Tanggal',
    'journal_add_post' => 'Entri',
    'journal_add_cta' => 'Simpan',
    'journal_blank_cta' => 'Tambahkan entri jurnal pertama Anda',
    'journal_blank_description' => 'Jurnal memungkinkan Anda menulis peristiwa yang terjadi pada Anda, dan mengingatnya.',
    'delete_confirmation' => 'Apakah Anda yakin ingin menghapus entri jurnal ini?',
];

==> monica-4.1.2.tgz: www/monica/resources/lang/id/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Bagaimana hari Anda? Anda bisa menilainya sekali setiap hari.',
    'journal_come_back' => 'Terima kasih. Kembalilah besok untuk menilai hari Anda lagi.',
    'journal_description' => 'Catatan: Jurnal mencantumkan entri jurnal mandiri, dan entri otomatis seperti Aktifitas yang telah selesai dilakukan dengan kontak Anda. Meskipun Anda dapat menghapus entri jurnal secara mandiri, Anda harus menghapus aktifitas secara langsung pada halaman kontak.',
    'journal_add' => 'Tambahkan sebuah entri jurnal',
    'journal_edit' => 'Sunting sebuah entri jurnal',
    'journal_empty' => 'Jurnal kosong',
    'journal_created_at' => 'Dibuat pada {date}',
    'journal_created_automatically' => 'Dibuat secara otomatis',
    'journal_entry_type_journal' => 'Entri jurnal',
    'journal_entry_type_activity' => 'Aktifitas',
    'journal_entry_rate' => 'Anda telah menilai hari Anda.',
    'journal_add_comment' => 'Apakah Anda ingin untuk menambahkan komentar (opsional)?',
    'journal_show_comment' => 'Tampilkan komentar',
    'entry_delete_success' => 'Entri jurnal telah berhasil dihapus.',
    'journal_add_title' => 'Judul (opsional)',
    'journal_add_date' => 'Tanggal',
    'journal_add_post' => 'Entri',
    'journal_add_cta' => 'Simpan',
    'journal_blank_cta' => 'Tambahkan entri jurnal pertama Anda',
    'journal_blank_description' => 'Jurnal memungkinkan Anda menulis peristiwa yang terjadi pada Anda, dan mengingatnya.',
    'delete_confirmation' => 'Apakah Anda yakin ingin menghapus entri jurnal ini?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
